pub enum DidChangeWorkspaceFolders {}Expand description
The workspace/didChangeWorkspaceFolders notification is sent from the client to the server to inform the server about workspace folder configuration changes
pub enum DidChangeWorkspaceFolders {}The workspace/didChangeWorkspaceFolders notification is sent from the client to the server to inform the server about workspace folder configuration changes