pub enum DocumentLinkRequest {}Expand description
The document links request is sent from the client to the server to request the location of links in a document.
pub enum DocumentLinkRequest {}The document links request is sent from the client to the server to request the location of links in a document.