pub enum DocumentLinkResolve {}Expand description
The document link resolve request is sent from the client to the server to resolve the target of a given document link.
pub enum DocumentLinkResolve {}The document link resolve request is sent from the client to the server to resolve the target of a given document link.