pub enum DocumentSymbolRequest {}Expand description
The document symbol request is sent from the client to the server to list all symbols found in a given text document.
pub enum DocumentSymbolRequest {}The document symbol request is sent from the client to the server to list all symbols found in a given text document.