pub enum FoldingRangeRequest {}Expand description
The folding range request is sent from the client to the server to return all folding ranges found in a given text document.
pub enum FoldingRangeRequest {}The folding range request is sent from the client to the server to return all folding ranges found in a given text document.