Enum languageserver_types::request::Formatting
source · pub enum Formatting {}Expand description
The document formatting request is sent from the server to the client to format a whole document.
pub enum Formatting {}The document formatting request is sent from the server to the client to format a whole document.