pub enum PrepareRenameRequest {}Expand description
The prepare rename request is sent from the client to the server to setup and test the validity of a rename operation at a given location.
pub enum PrepareRenameRequest {}The prepare rename request is sent from the client to the server to setup and test the validity of a rename operation at a given location.