Enum languageserver_types::request::References
source · pub enum References {}Expand description
The references request is sent from the client to the server to resolve project-wide references for the symbol denoted by the given text document position.