pub enum WorkspaceFoldersRequest {}
The workspace/workspaceFolders request is sent from the server to the client to fetch the current open list of
workspace folders. Returns null in the response if only a single file is open in the tool.
Returns an empty array if a workspace is open but no folders are configured.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.