pub enum WorkspaceSymbol {}Expand description
The workspace symbol request is sent from the client to the server to list project-wide symbols matching the query string.
pub enum WorkspaceSymbol {}The workspace symbol request is sent from the client to the server to list project-wide symbols matching the query string.