pub struct CompletionItem {Show 14 fields
pub label: String,
pub kind: Option<CompletionItemKind>,
pub detail: Option<String>,
pub documentation: Option<Documentation>,
pub deprecated: Option<bool>,
pub preselect: Option<bool>,
pub sort_text: Option<String>,
pub filter_text: Option<String>,
pub insert_text: Option<String>,
pub insert_text_format: Option<InsertTextFormat>,
pub text_edit: Option<TextEdit>,
pub additional_text_edits: Option<Vec<TextEdit>>,
pub command: Option<Command>,
pub data: Option<Value>,
}Fields
label: StringThe label of this completion item. By default also the text that is inserted when selecting this completion.
kind: Option<CompletionItemKind>The kind of this completion item. Based of the kind an icon is chosen by the editor.
detail: Option<String>A human-readable string with additional information about this item, like type or symbol information.
documentation: Option<Documentation>A human-readable string that represents a doc-comment.
deprecated: Option<bool>Indicates if this item is deprecated.
preselect: Option<bool>Select this item when showing.
sort_text: Option<String>A string that shoud be used when comparing this item
with other items. When falsy the label is used.
filter_text: Option<String>A string that should be used when filtering a set of
completion items. When falsy the label is used.
insert_text: Option<String>A string that should be inserted a document when selecting
this completion. When falsy the label is used.
insert_text_format: Option<InsertTextFormat>The format of the insert text. The format applies to both the insertText property
and the newText property of a provided textEdit.
text_edit: Option<TextEdit>An edit which is applied to a document when selecting this completion. When an edit is provided the value of insertText is ignored.
additional_text_edits: Option<Vec<TextEdit>>An optional array of additional text edits that are applied when selecting this completion. Edits must not overlap with the main edit nor with themselves.
command: Option<Command>An optional command that is executed after inserting this completion. Note that additional modifications to the current document should be described with the additionalTextEdits-property.
data: Option<Value>An data entry field that is preserved on a completion item between a completion and a completion resolve request.
Implementations
Sourceimpl CompletionItem
impl CompletionItem
Sourcepub fn new_simple(label: String, detail: String) -> CompletionItem
pub fn new_simple(label: String, detail: String) -> CompletionItem
Create a CompletionItem with the minimum possible info (label and detail).