pub struct InitializeParams {
pub process_id: Option<u64>,
pub root_path: Option<String>,
pub root_uri: Option<Url>,
pub initialization_options: Option<Value>,
pub capabilities: ClientCapabilities,
pub trace: Option<TraceOption>,
pub workspace_folders: Option<Vec<WorkspaceFolder>>,
}Fields
process_id: Option<u64>The process Id of the parent process that started the server. Is null if the process has not been started by another process. If the parent process is not alive then the server should exit (see exit notification) its process.
root_path: Option<String>The rootPath of the workspace. Is null if no folder is open.
root_uri: Option<Url>The rootUri of the workspace. Is null if no
folder is open. If both rootPath and rootUri are set
rootUri wins.
initialization_options: Option<Value>User provided initialization options.
capabilities: ClientCapabilitiesThe capabilities provided by the client (editor)
trace: Option<TraceOption>The initial trace setting. If omitted trace is disabled (‘off’).
workspace_folders: Option<Vec<WorkspaceFolder>>The workspace folders configured in the client when the server starts.
This property is only available if the client supports workspace folders.
It can be null if the client supports workspace folders but none are
configured.